@@ -26,6 +26,7 @@ import pickle
 from defSim.tools import ClusterExecutionScript
 import shutil
 import copy
+import pathlib
 
 
 def call_simulation_run(simulation):
@@ -95,6 +96,7 @@ class Experiment:
         output_file_types (List[str or DataFileCreator]): Determines which types of output files will be saved at output_folder_path. See tools.CreateDataFiles for options.
         repetitions (int = 1): How often each simulation should be repeated.
         seed (int = random.randint(10000, 99999)): Optionally set seed for replicability.
+        parameter_dict (dict = {}):  A dictionary with all parameters that will be passed to the specific component implementations.
     """
 
     def __init__(self,
@@ -123,7 +125,8 @@ class Experiment:
                  output_folder_path: str or pathlib.Path = None,
                  output_file_types: List[str or DataFileCreator] = [],                 
                  repetitions: int = 1,
-                 seed: int = None):
+                 seed: int = None,
+                 parameter_dict: dict = {}):
         self.simulations = simulations
         self.network = network
         self.communication_regime = {"communication_regime": communication_regime}
@@ -150,6 +153,7 @@ class Experiment:
         self.output_file_types = output_file_types        
         self.repetitions = repetitions
         self.seed = seed
+        self.parameter_dict = parameter_dict
         self.parameter_dict_list = []  # this is the internal dictionary that is created by permuting all parameters
 
     def estimate_runtime(self, sample_runs: int = None, sample_steps: int = 10):
@@ -205,7 +209,7 @@ class Experiment:
                 simulations_to_run.append(
                     Simulation(network=self.network.copy() if self.network is not None else self.network,
                                topology=self.topology,
-			       network_modifiers=self.network_modifiers,
+			                   network_modifiers=self.network_modifiers,
                                attributes_initializer=self.attributes_initializer,
                                focal_agent_selector=self.focal_agent_selector,
                                neighbor_selector=self.neighbor_selector,
@@ -316,7 +320,6 @@ class Experiment:
 
             if len(self.parameter_dict_list) == 0:
                 self.parameter_dict_list = self._create_parameter_dictionaries()
-            print("%d different parameter combinations" % len(self.parameter_dict_list))
             if parallel:
                 pool = mp.Pool(processes=num_cores)
 
@@ -417,7 +420,7 @@ class Experiment:
     def _create_and_run_simulation(self, parameter_dict):
         simulation = Simulation(network=self.network.copy() if isinstance(self.network, nx.Graph) else self.network,
                                 topology=self.topology,
-				network_modifiers=self.network_modifiers,
+				                network_modifiers=self.network_modifiers,
                                 attributes_initializer=self.attributes_initializer,
                                 focal_agent_selector=self.focal_agent_selector,
                                 neighbor_selector=self.neighbor_selector,
@@ -442,7 +445,8 @@ class Experiment:
         If a seed is set for the experiment, this also creates an individual seed for each simulation.
 
         """
-        dictionaries = [self.network_parameters,
+        dictionaries = [self.parameter_dict,
+                        self.network_parameters,
                         self.attribute_parameters,
                         self.communication_regime,
                         self.stop_condition_parameters,
