@@ -7,6 +7,7 @@ import random
 from math import inf
 import warnings
 import time
+import pathlib
 import pandas as pd
 import numpy as np
 import networkx as nx
@@ -74,7 +75,7 @@ class Simulation:
                  output_realizations=[],
                  output_folder_path: str or pathlib.Path = None,
                  output_file_types: List[str or DataFileCreator] = [],
-                 tickwise: List[str] = []
+                 tickwise: List[str] or List[CreateOutputTable.OutputTableCreator] = []
                  ):
         self.network = network
         self.topology = topology
@@ -113,9 +114,9 @@ class Simulation:
             if tickwise_realization in CreateOutputTable._implemented_output_realizations:
                 self.tickwise_output['defaults'] = []
             else:
-                if inspect.isclass(tickwise_realization) and issubclass(tickwise_realization,
-                                                                        CreateOutputTable.OutputTableCreator):
-                    tickwise_realization = tickwise_realization()
+                if inspect.isclass(tickwise_realization):
+                    if issubclass(tickwise_realization, CreateOutputTable.OutputTableCreator):
+                        tickwise_realization = tickwise_realization()
                 if isinstance(tickwise_realization, CreateOutputTable.OutputTableCreator):
                     if tickwise_realization.label != "":
                         self.tickwise_output[tickwise_realization.label] = []
@@ -225,7 +226,7 @@ class Simulation:
             ## apply network modifiers
             if self.network_modifiers is not None:
                 for modifier in self.network_modifiers:
-                    modifier.rewire_network(network)
+                    modifier.rewire_network(self.network)
         else:
             self.network = network_init.generate_network(self.topology, network_modifiers=self.network_modifiers,
                                                          **self.parameter_dict)
