@@ -115,10 +115,14 @@ def initialize_attributes(network: nx.Graph, realization: str, **kwargs):
         RandomContinuousInitializer.RandomContinuousInitializer(**kwargs).initialize_attributes(network)
     elif realization == 'correlated_continuous':
         CorrelatedContinuousInitializer.CorrelatedContinuousInitializer(**kwargs).initialize_attributes(network)  
+    elif isinstance(realization, AttributesInitializer):
+        realization.initialize_attributes(network, **kwargs)
     elif issubclass(realization, AttributesInitializer):
         realization(**kwargs).initialize_attributes(network, **kwargs)
     else:
-        raise ValueError("Can only select from the options ['random_categorical', 'random_continuous', 'correlated_continuous'] or supply an instance of a class which inherits from the ABC")
+        raise ValueError("Can only select from the options "
+                         "['random_categorical', 'random_continuous', 'correlated_continuous'] "
+                         "or supply an instance of a class or a subclass which inherits from AttributesInitializer")
 
 
 def set_categorical_attribute(network: nx.Graph, name: str, values: list, distribution: str = "uniform", **kwargs):
@@ -159,11 +163,7 @@ def set_continuous_attribute(network: nx.Graph, name: str, shape: tuple = (1), d
     if not distribution in ["uniform", "normal", "beta", "triangular"]:
         raise NotImplementedError("The selected distribution has not been implemented. Select from: [uniform, normal, beta, triangular].")
 
-    try:
-        rng = kwargs["np_random_generator"]
-    except KeyError:
-        warnings.warn("No Numpy Generator in parameter dictionary, creating default")
-        rng = np.random.default_rng()
+    rng = kwargs.get("np_random_generator", np.random.default_rng())
 
     # NOTE: it would probably be faster to let numpy draw all random values at once, and then assign them
     # that's something we can do if this ever becomes a performance issue (which it likely won't)
@@ -192,6 +192,6 @@ def set_continuous_attribute(network: nx.Graph, name: str, shape: tuple = (1), d
     elif distribution == "triangular":
         # with default value mode loc = 0.5, the mode of the triangular distribution
         # is at 0.5 and the distribution is symmetrical over the interval [0,1]
-        loc = kwags.get("loc", 0.5)
+        loc = kwargs.get("loc", 0.5)
         for i in network.nodes():
             network.nodes[i][name] = rng.triangular(left = 0, mode = loc, right = 1)        
\ No newline at end of file
